@@ -55,28 +55,73 @@ def lister_paires_test(liste, fonction_test, cle_de_tri_1, cle_de_tri_2):
     liste_paires_test.sort(key = cle_de_tri_1)
     return liste_paires_test
 
-
-if __name__ == "__main__":
-    bdt = BaseTemps([0,1], 1e-3)
-
-    N = 4
-    liste = []
-    for i in range(N):
-        liste.append(SignalBase(bdt))
-
-    print(str_liste(liste, begin = "(", end = ")"))
-    N1, N2 = 3, 2
-    liste_de_listes = []
-    for i in range(N1):
-        liste = []
-        for i in range(N2):
-            liste.append(SignalBase(bdt))
-        liste_de_listes.append(liste)
-
-    print(str_liste_de_listes(liste_de_listes))
-
-
 def periodiser(N, vecteur_signal_periode):
     Nperiode = len(vecteur_signal_periode)
     Pperiodes = int(np.ceil(N/Nperiode))
     return np.concatenate([vecteur_signal_periode]*Pperiodes)[0:N]
+
+def analyser_kwargs(kwargs, nom_variable, fonction_test, valeur_par_defaut):
+    valeur = kwargs.get(nom_variable, None)
+    if nom_variable in kwargs:
+        valeur = kwargs.get(nom_variable)
+        del kwargs[nom_variable]
+        test = True
+    else:
+        valeur = valeur_par_defaut
+        test = False
+
+    if not fonction_test(valeur):
+        print("Erreur dans l'analyse de arguments {0} = {1} est impossible".format(nom_variable, valeur))
+        sys.exit()
+    return valeur, test
+
+def analyser_args(args, nom_variable, fonction_test, valeur_par_defaut):
+    if len(args) > 0:
+        valeur = args.pop(0)
+        test = True
+    else:
+        valeur = valeur_par_defaut
+        test = False
+
+    if not fonction_test(valeur):
+        print("Erreur dans l'analyse de arguments {0} = {1} est impossible".format(nom_variable, valeur))
+        sys.exit()
+    return valeur, test
+
+def analyser_args_kwargs(args, kwargs, nom_variable, fonction_test, valeur_par_defaut):
+    valeur_args, test_args = analyser_args(args, nom_variable, fonction_test, valeur_par_defaut)
+    valeur_kwargs, test_kwargs = analyser_kwargs(kwargs, nom_variable, fonction_test, valeur_par_defaut)
+    if test_args == test_kwargs == True:
+        print("Erreur dans l'analyse de arguments {0} est défini deux fois".format(nom_variable))
+        sys.exit()
+    elif test_kwargs:
+        return valeur_kwargs
+    else:
+        return valeur_args
+
+
+
+if __name__ == "__main__":
+    # bdt = BaseTemps([0,1], 1e-3)
+
+    # N = 4
+    # liste = []
+    # for i in range(N):
+    #     liste.append(SignalBase(bdt))
+
+    # print(str_liste(liste, begin = "(", end = ")"))
+    # N1, N2 = 3, 2
+    # liste_de_listes = []
+    # for i in range(N1):
+    #     liste = []
+    #     for i in range(N2):
+    #         liste.append(SignalBase(bdt))
+    #     liste_de_listes.append(liste)
+
+    # print(str_liste_de_listes(liste_de_listes))
+
+    args = []#["zorro", 2, BaseTemps([0,1], 1e-3)]
+    kwargs = {}
+    kwargs["arg1"] = "bidon"
+
+    print(analyser_args_kwargs(args, kwargs, "arg1", lambda x: isinstance(x, str), "superman"))
\ No newline at end of file
